@@ -2,11 +2,11 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-ar.c,v 1.22 2008/03/18 19:41:40 msk Exp $
+**  $Id: dkim-ar.c,v 1.24 2008/04/10 18:23:43 msk Exp $
 */
 
 #ifndef lint
-static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.22 2008/03/18 19:41:40 msk Exp $";
+static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.24 2008/04/10 18:23:43 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -26,6 +26,7 @@ static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.22 2008/03/18 19:41:40 msk
 #define	ARES_ENDOF(x)		((x) + sizeof(x) - 1)
 #define	ARES_STRORNULL(x)	((x) == NULL ? "(null)" : (x))
 #define	ARES_TOKENS		";=."
+#define	ARES_TOKENS2		"=."
 
 #define	ARES_MAXTOKENS		512
 
@@ -198,6 +199,13 @@ ares_tokenize(u_char *input, u_char *outbuf, size_t outbuflen,
 		}
 		else if (strchr(ARES_TOKENS, *p) != NULL) /* delimiter */
 		{
+			if (parens > 0)
+			{
+				*q = *p;
+				q++;
+				continue;
+			}
+
 			if (intok)
 			{
 				intok = FALSE;
@@ -367,6 +375,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 	int c;
 	int r;
 	int state;
+	int prevstate;
 	u_char *p;
 	u_char tmp[DKIM_MAXHEADER + 2];
 	u_char *tokens[ARES_MAXTOKENS];
@@ -381,6 +390,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 	if (ntoks == -1 || ntoks > ARES_MAXTOKENS)
 		return -1;
 
+	prevstate = -1;
 	state = 0;
 	n = 0;
 
@@ -398,16 +408,30 @@ ares_parse(u_char *hdr, struct authres *ar)
 			    !isalnum(tokens[c][0]))
 				return -1;
 
-			sm_strlcpy(ar->ares_host, tokens[c],
+			sm_strlcat(ar->ares_host, tokens[c],
 			           sizeof ar->ares_host);
 
+			prevstate = state;
 			state = 1;
 
 			break;
 
 		  case 1:				/* [version] */
+			if (tokens[c][0] == '.' &&
+			    tokens[c][1] == '\0' && prevstate == 0)
+			{
+				sm_strlcat(ar->ares_host, tokens[c],
+				           sizeof ar->ares_host);
+
+				prevstate = state;
+				state = 0;
+
+				break;
+			}
+
 			if (tokens[c][0] == ';')
 			{
+				prevstate = state;
 				state = 3;
 			}
 			else if (isascii(tokens[c][0]) &&
@@ -416,6 +440,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 				sm_strlcpy(ar->ares_version, tokens[c],
 				           sizeof ar->ares_version);
 
+				prevstate = state;
 				state = 2;
 			}
 			else
@@ -430,6 +455,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 			    tokens[c][1] != '\0')
 				return -1;
 
+			prevstate = state;
 			state = 3;
 
 			break;
@@ -440,6 +466,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 
 			ar->ares_result[n - 1].result_method = ares_convert(methods,
 			                                                    tokens[c]);
+			prevstate = state;
 			state = 4;
 
 			break;
@@ -449,6 +476,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 			    tokens[c][1] != '\0')
 				return -1;
 
+			prevstate = state;
 			state = 5;
 
 			break;
@@ -456,6 +484,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 		  case 5:				/* result */
 			ar->ares_result[n - 1].result_result = ares_convert(aresults,
 			                                                    tokens[c]);
+			prevstate = state;
 			state = 6;
 
 			break;
@@ -465,6 +494,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 			    tokens[c][1] != '\0')
 				return -1;
 
+			prevstate = state;
 			state = 8;
 
 			break;
@@ -474,6 +504,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 			           tokens[c],
 			           sizeof ar->ares_result[n - 1].result_reason);
 
+			prevstate = state;
 			state = 9;
 
 			break;
@@ -482,6 +513,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 			if (tokens[c][0] == ';' &&	/* neither */
 			    tokens[c][1] == '\0')
 			{
+				prevstate = state;
 				state = 3;
 
 				continue;
@@ -489,21 +521,40 @@ ares_parse(u_char *hdr, struct authres *ar)
 
 			if (strcasecmp(tokens[c], "reason") == 0)
 			{				/* reason */
+				prevstate = state;
 				state = 7;
 
 				continue;
 			}
 			else
 			{
+				prevstate = state;
 				state = 9;
 			}
 
 			/* FALLTHROUGH */
 
 		  case 9:				/* ptype */
+			if (prevstate == 13 &&
+			    strchr(ARES_TOKENS2, tokens[c][0]) != NULL &&
+			    tokens[c][1] == '\0')
+			{
+				r--;
+
+				sm_strlcat(ar->ares_result[n - 1].result_value[r],
+				           tokens[c],
+				           sizeof ar->ares_result[n - 1].result_value[r]);
+
+				prevstate = state;
+				state = 13;
+
+				continue;
+			}
+
 			if (tokens[c][0] == ';' &&
 			    tokens[c][1] == '\0')
 			{
+				prevstate = state;
 				state = 3;
 
 				continue;
@@ -518,6 +569,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 
 				ar->ares_result[n - 1].result_ptype[r] = x;
 
+				prevstate = state;
 				state = 10;
 			}
 
@@ -528,6 +580,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 			    tokens[c][1] != '\0')
 				return -1;
 
+			prevstate = state;
 			state = 11;
 
 			break;
@@ -537,6 +590,7 @@ ares_parse(u_char *hdr, struct authres *ar)
 			           tokens[c],
 			           sizeof ar->ares_result[n - 1].result_property[r]);
 
+			prevstate = state;
 			state = 12;
 
 			break;
@@ -546,17 +600,19 @@ ares_parse(u_char *hdr, struct authres *ar)
 			    tokens[c][1] != '\0')
 				return -1;
 
+			prevstate = state;
 			state = 13;
 
 			break;
 
 		  case 13:				/* value */
-			sm_strlcpy(ar->ares_result[n - 1].result_value[r],
+			sm_strlcat(ar->ares_result[n - 1].result_value[r],
 			           tokens[c],
 			           sizeof ar->ares_result[n - 1].result_value[r]);
 			r++;
 			ar->ares_result[n - 1].result_props = r;
 
+			prevstate = state;
 			state = 9;
 
 			break;
