@@ -2,18 +2,19 @@
 **  Copyright (c) 2006-2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-config.h,v 1.51 2008/03/04 22:50:22 msk Exp $
+**  $Id: dkim-config.h,v 1.53 2008/04/04 22:01:33 msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
 #ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.51 2008/03/04 22:50:22 msk Exp $";
+static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.53 2008/04/04 22:01:33 msk Exp $";
 #endif /* !lint */
 
 struct configdef dkimf_config[] =
 {
+	{ "AllowSHA1Only",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysAddARHeader",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysSignHeaders",		CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_AUTHSERV_JOBID
@@ -41,6 +42,7 @@ struct configdef dkimf_config[] =
 	{ "KeyList",			CONFIG_TYPE_STRING,	FALSE },
 	{ "Include",			CONFIG_TYPE_INCLUDE,	FALSE },
 	{ "InternalHosts",		CONFIG_TYPE_STRING,	FALSE },
+	{ "LogWhy",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "MaximumHeaders",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "MaximumSignedBytes",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "MacroList",			CONFIG_TYPE_STRING,	FALSE },
