@@ -2,11 +2,11 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-testkey.c,v 1.6 2008/01/18 22:13:07 msk Exp $
+**  $Id: dkim-testkey.c,v 1.8 2008/02/14 00:34:52 msk Exp $
 */
 
 #ifndef lint
-static char dkim_testkey_c[] = "@(#)$Id: dkim-testkey.c,v 1.6 2008/01/18 22:13:07 msk Exp $";
+static char dkim_testkey_c[] = "@(#)$Id: dkim-testkey.c,v 1.8 2008/02/14 00:34:52 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -32,6 +32,10 @@ static char dkim_testkey_c[] = "@(#)$Id: dkim-testkey.c,v 1.6 2008/01/18 22:13:0
 /* macros */
 #define	CMDLINEOPTS	"d:k:s:"
 
+/* prototypes */
+void dkimf_log_ssl_errors(void);
+int usage(void);
+
 /* globals */
 char *progname;
 
