@@ -2,14 +2,14 @@
 **  Copyright (c) 2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: stats.h,v 1.4 2007/06/27 19:49:23 msk Exp $
+**  $Id: stats.h,v 1.5 2007/09/07 00:28:57 msk Exp $
 */
 
 #ifndef _STATS_H_
 #define _STATS_H_
 
 #ifndef lint
-static char stats_h_id[] = "@(#)$Id: stats.h,v 1.4 2007/06/27 19:49:23 msk Exp $";
+static char stats_h_id[] = "@(#)$Id: stats.h,v 1.5 2007/09/07 00:28:57 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -26,16 +26,12 @@ static char stats_h_id[] = "@(#)$Id: stats.h,v 1.4 2007/06/27 19:49:23 msk Exp $
 /* libdkim includes */
 #include <dkim.h>
 
-#ifndef MAXHOSTNAMELEN
-# define MAXHOSTNAMELEN	256
-#endif /* ! MAXHOSTNAMELEN */
-
 /* data types */
 struct dkim_stats_key
 {
 	dkim_canon_t	sk_hdrcanon;
 	dkim_canon_t	sk_bodycanon;
-	char		sk_sigdomain[MAXHOSTNAMELEN + 1];
+	char		sk_sigdomain[DKIM_MAXHOSTNAMELEN + 1];
 };
 
 struct dkim_stats_data
