@@ -2,11 +2,11 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: test.c,v 1.28 2008/01/18 22:10:49 msk Exp $
+**  $Id: test.c,v 1.29 2008/02/17 21:18:45 msk Exp $
 */
 
 #ifndef lint
-static char test_c_id[] = "@(#)$Id: test.c,v 1.28 2008/01/18 22:10:49 msk Exp $";
+static char test_c_id[] = "@(#)$Id: test.c,v 1.29 2008/02/17 21:18:45 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -54,6 +54,14 @@ char *envfrom[] =
 	NULL
 };
 
+#ifdef _FFR_BODYLENGTH_DB
+char *envrcpt[] =
+{
+	"test@example.com",
+	NULL
+};
+#endif /* _FFR_BODYLENGTH_DB */
+
 #define	FCLOSE(x)		if ((x) != stdin) \
 					fclose((x));
 #define	MLFI_OUTPUT(x,y)	((y) > 1 || ((y) == 1 && (x) != SMFIS_CONTINUE))
@@ -293,6 +301,20 @@ dkimf_testfile(DKIM_LIB *libdkim, char *file, time_t fixedtime, bool strict,
 		return EX_SOFTWARE;
 	}
 
+#ifdef _FFR_BODYLENGTH_DB
+	ms = mlfi_envrcpt((SMFICTX *) tctx, envrcpt);
+	if (MLFI_OUTPUT(ms, tverbose))
+	{
+		fprintf(stderr, "%s: %s: mlfi_envrcpt() returned %s\n",
+		        progname, file, milter_status[ms]);
+	}
+	if (ms != SMFIS_CONTINUE)
+	{
+		FCLOSE(f);
+		return EX_SOFTWARE;
+	}
+#endif /* _FFR_BODYLENGTH_DB */
+
 	while (!feof(f))
 	{
 		if (fgets(line, sizeof line, f) == NULL)
