@@ -2,11 +2,11 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.c,v 1.69 2008/02/18 02:53:28 msk Exp $
+**  $Id: util.c,v 1.70 2008/04/17 17:08:19 msk Exp $
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.69 2008/02/18 02:53:28 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.70 2008/04/17 17:08:19 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -384,13 +384,6 @@ bool
 dkimf_checkip(Peer list, struct sockaddr *ip)
 {
 	bool out = FALSE;
-	int bits;
-	char *p;
-	char *q;
-	struct Peer *node;
-	struct in_addr addr;
-	struct in_addr mask;
-	struct in_addr compare;
 	char ipbuf[DKIM_MAXHOSTNAMELEN + 1];
 
 	assert(ip != NULL);
@@ -402,10 +395,12 @@ dkimf_checkip(Peer list, struct sockaddr *ip)
 #if NETINET6
 	if (ip->sa_family == AF_INET6)
 	{
+		struct sockaddr_in6 sin6;
 		struct in6_addr addr;
 
-		memcpy(&addr, &((struct sockaddr_in6 *)ip)->sin6_addr,
-		       sizeof addr);
+		memcpy(&sin6, ip, sizeof sin6);
+
+		memcpy(&addr, &sin6.sin6_addr, sizeof addr);
 
 		if (IN6_IS_ADDR_V4MAPPED(&addr))
 		{
@@ -437,62 +432,75 @@ dkimf_checkip(Peer list, struct sockaddr *ip)
 	}
 #endif /* NETINET6 */
 
-	/* walk the list */
-	for (node = list; node != NULL; node = node->peer_next)
+	if (ip->sa_family == AF_INET)
 	{
-		memcpy(&addr.s_addr, &((struct sockaddr_in *)ip)->sin_addr,
-		       sizeof(addr.s_addr));
+		int bits;
+		char *p;
+		char *q;
+		struct Peer *node;
+		struct in_addr addr;
+		struct in_addr mask;
+		struct in_addr compare;
+		struct sockaddr_in sin;
 
-		/* try the IP direct match */
-		(void) dkimf_inet_ntoa(addr, ipbuf, sizeof ipbuf);
-		if (strcmp(ipbuf, node->peer_info) == 0)
+		memcpy(&sin, ip, sizeof sin);
+
+		memcpy(&addr.s_addr, &sin.sin_addr, sizeof addr.s_addr);
+
+		/* walk the list */
+		for (node = list; node != NULL; node = node->peer_next)
 		{
-			out = !node->peer_neg;
-			continue;
-		}
+			/* try the IP direct match */
+			(void) dkimf_inet_ntoa(addr, ipbuf, sizeof ipbuf);
+			if (strcmp(ipbuf, node->peer_info) == 0)
+			{
+				out = !node->peer_neg;
+				continue;
+			}
 
-		/* try the IP/CIDR and IP/mask possibilities */
-		p = strchr(node->peer_info, '/');
-		if (p == NULL)
-			continue;
+			/* try the IP/CIDR and IP/mask possibilities */
+			p = strchr(node->peer_info, '/');
+			if (p == NULL)
+				continue;
 
-		*p = '\0';
-		compare.s_addr = inet_addr(node->peer_info);
-		if (compare.s_addr == INADDR_NONE)
-		{
-			*p = '/';
-			continue;
-		}
-
-		bits = strtoul(p + 1, &q, 10);
-
-		if (*q == '.')
-		{
-			mask.s_addr = inet_addr(p + 1);
-			if (mask.s_addr == INADDR_NONE)
+			*p = '\0';
+			compare.s_addr = inet_addr(node->peer_info);
+			if (compare.s_addr == INADDR_NONE)
 			{
 				*p = '/';
 				continue;
 			}
-		}
-		else if (*q != '\0')
-		{
+
+			bits = strtoul(p + 1, &q, 10);
+
+			if (*q == '.')
+			{
+				mask.s_addr = inet_addr(p + 1);
+				if (mask.s_addr == INADDR_NONE)
+				{
+					*p = '/';
+					continue;
+				}
+			}
+			else if (*q != '\0')
+			{
+				*p = '/';
+				continue;
+			}
+			else
+			{
+				int c;
+
+				mask.s_addr = 0;
+				for (c = 0; c < bits; c++)
+					mask.s_addr |= htonl(1 << (31 - c));
+			}
+
+			if ((addr.s_addr & mask.s_addr) == (compare.s_addr & mask.s_addr))
+				out = !node->peer_neg;
+
 			*p = '/';
-			continue;
 		}
-		else
-		{
-			int c;
-
-			mask.s_addr = 0;
-			for (c = 0; c < bits; c++)
-				mask.s_addr |= htonl(1 << (31 - c));
-		}
-
-		if ((addr.s_addr & mask.s_addr) == (compare.s_addr & mask.s_addr))
-			out = !node->peer_neg;
-
-		*p = '/';
 	}
 
 	return out;
