@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char dkim_test_c_id[] = "@(#)$Id: dkim-test.c,v 1.8 2007/12/03 07:43:25 msk Exp $";
+static char dkim_test_c_id[] = "@(#)$Id: dkim-test.c,v 1.9 2008/02/26 00:04:31 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -245,11 +245,15 @@ dkim_test_key(DKIM_LIB *lib, char *selector, char *domain,
 }
 
 /*
-**  DKIM_TEST_SSP -- verify that a valid sender signing policy exists in dns
+**  DKIM_TEST_ASP -- verify that a valid author signing policy exists in dns
 **
 **  Parameters:
 **  	lib -- DKIM library handle
 **  	domain -- domain name
+**  	presult -- policy discovered (returned)
+**  	presult2 -- policy stage at which result was decided (returned)
+**  	err -- error buffer
+**  	errlen -- bytes available at "err"
 **
 **  Return value:
 **  	0 -- some kind of result was made available
@@ -257,20 +261,15 @@ dkim_test_key(DKIM_LIB *lib, char *selector, char *domain,
 */
 
 int
-dkim_test_ssp(DKIM_LIB *lib, char *domain, dkim_policy_t *presult,
-              dkim_handling_t *hresult, int *presult2,
-              char *err, size_t errlen)
+dkim_test_asp(DKIM_LIB *lib, char *domain, dkim_policy_t *presult,
+              int *presult2, char *err, size_t errlen)
 {
 	DKIM_STAT stat;
-	bool test = FALSE;
-	bool susp = FALSE;
 	dkim_policy_t pcode = DKIM_POLICY_DEFAULT;
-	dkim_handling_t hcode = DKIM_HANDLING_DEFAULT;
 	DKIM *dkim;
 
 	assert(lib != NULL);
 	assert(presult != NULL);
-	assert(hresult != NULL);
 	assert(presult2 != NULL);
 
 	dkim = dkim_verify(lib, "test", NULL, &stat);
@@ -285,7 +284,7 @@ dkim_test_ssp(DKIM_LIB *lib, char *domain, dkim_policy_t *presult,
 	dkim->dkim_domain = domain;
 	dkim->dkim_sigcount = 0;
 
-	stat = dkim_policy(dkim, &test, &susp, &pcode, &hcode, NULL);
+	stat = dkim_policy(dkim, &pcode, NULL);
 	if (stat != DKIM_STAT_OK)
 	{
 		if (err != NULL)
@@ -311,7 +310,6 @@ dkim_test_ssp(DKIM_LIB *lib, char *domain, dkim_policy_t *presult,
 	}
 
 	*presult = pcode;
-	*hresult = hcode;
 	*presult2 = dkim_getpresult(dkim);
 
 	dkim->dkim_domain = NULL;
