@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_setup_c_id[] = "@(#)$Id: t-setup.c,v 1.7 2008/01/15 20:58:46 msk Exp $";
+static char t_setup_c_id[] = "@(#)$Id: t-setup.c,v 1.8 2008/04/08 22:03:38 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -61,6 +61,14 @@ main(int argc, char **argv)
 	}
 	fprintf(f, "\n");
 
+	fprintf(f, "%s.%s.%s ", SELECTOR2, DKIM_DNSKEYNAME, DOMAIN2);
+	for (p = PUBLICKEYG; *p != '\0'; p++)
+	{
+		if (*p != '\n')
+			putc(*p, f);
+	}
+	fprintf(f, "\n");
+
 	fprintf(f, "%s.%s.%s ", DKIM_DNSPOLICYNAME, DKIM_DNSKEYNAME, DOMAIN2);
 	fprintf(f, "dkim=all; r=%s\n", REPLYADDRESS);
 
