@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.9 2007/10/24 06:25:57 msk Exp $";
+static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.10 2008/04/08 23:18:59 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -48,6 +48,7 @@ main(int argc, char **argv)
 
 	int status;
 	int err;
+	u_int s1, s2, s3;
 	size_t buflen;
 	DB *cache;
 	char buf[BUFRSZ + 1];
@@ -87,6 +88,17 @@ main(int argc, char **argv)
 	assert(err == 0);
 	assert(status == 1);
 
+	printf("--- expire old records\n");
+	status = dkim_cache_expire(cache, 3, &err);
+	assert(err == 0);
+	assert(status == 1);
+
+	printf("--- retrieve cache stats\n");
+	dkim_cache_stats(&s1, &s2, &s3);
+	assert(s1 == 3);
+	assert(s2 == 1);
+	assert(s3 == 1);
+
 	dkim_cache_close(cache);
 #endif /* ! QUERY_CACHE */
 
