@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test52_c_id[] = "@(#)$Id: t-test52.c,v 1.8 2007/08/20 16:52:04 msk Exp $";
+static char t_test52_c_id[] = "@(#)$Id: t-test52.c,v 1.9 2007/09/17 16:35:49 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -40,7 +40,7 @@ main(int argc, char **argv)
 
 #else /* ! DKIM_SIGN_RSASHA256 */
 
-	u_int flags;
+	u_int flags = 0;
 	DKIM_STAT status;
 	time_t fixed_time;
 	DKIM *dkim;
