@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test54_c_id[] = "@(#)$Id: t-test54.c,v 1.6 2007/07/27 05:39:47 msk Exp $";
+static char t_test54_c_id[] = "@(#)$Id: t-test54.c,v 1.7 2007/10/07 13:04:02 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -48,10 +48,10 @@ char *signheaders[] =
 int
 main(int argc, char **argv)
 {
-#if !defined(DKIM_SIGN_RSASHA256) || !defined(_FFR_SELECT_SIGN_HEADERS)
+#ifndef DKIM_SIGN_RSASHA256
 	printf("*** relaxed/simple rsa-sha256 signing with header selection SKIPPED\n");
 
-#else /* !defined(DKIM_SIGN_RSASHA256) || !defined(_FFR_SELECT_SIGN_HEADERS) */
+#else /* ! DKIM_SIGN_RSASHA256 */
 
 # ifdef TEST_KEEP_FILES
 	u_int flags;
@@ -63,7 +63,7 @@ main(int argc, char **argv)
 	dkim_sigkey_t key;
 	unsigned char hdr[MAXHEADER + 1];
 
-	printf("*** relaxed/simple rsa-sha256 signing with header omission\n");
+	printf("*** relaxed/simple rsa-sha256 signing with header selection\n");
 
 	/* instantiate the library */
 	lib = dkim_init(NULL, NULL);
@@ -190,7 +190,7 @@ main(int argc, char **argv)
 	assert(status == DKIM_STAT_OK);
 
 	dkim_close(lib);
-#endif /* !defined(DKIM_SIGN_RSASHA256) || !defined(_FFR_SELECT_SIGN_HEADERS) */
+#endif /* ! DKIM_SIGN_RSASHA256 */
 
 	return 0;
 }
