@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.5 2007/12/12 00:16:25 msk Exp $";
+static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.7 2008/02/29 00:37:22 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -42,10 +42,7 @@ main(int argc, char **argv)
 
 	int hfd;
 	int bfd;
-	bool test;
-	bool susp;
 	dkim_policy_t pcode = DKIM_POLICY_NONE;
-	dkim_handling_t hcode = DKIM_HANDLING_NONE;
 	u_int flags;
 	DKIM_STAT status;
 	DKIM *dkim;
@@ -156,20 +153,15 @@ main(int argc, char **argv)
 	assert(status == DKIM_STAT_BADSIG);
 
 	/* set up for the rest */
-	test = FALSE;
-	susp = FALSE;
 	hfd = -1;
 	bfd = -1;
 	sig = dkim_getsignature(dkim);
 	assert(sig != NULL);
 
 	/* policy query, verify correct result */
-	status = dkim_policy(dkim, &test, &susp, &pcode, &hcode, NULL);
+	status = dkim_policy(dkim, &pcode, NULL);
 	assert(status == DKIM_STAT_OK);
-	assert(!test);
-	assert(susp);
 	assert(pcode == DKIM_POLICY_ALL);
-	assert(hcode == DKIM_HANDLING_PROCESS);
 
 	/* request report info, verify valid descriptors and address */
 	status = dkim_reportinfo(dkim, sig, &hfd, &bfd, addr, sizeof addr);
