@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test86_c_id[] = "@(#)$Id: t-test86.c,v 1.3 2008/02/26 00:45:18 msk Exp $";
+static char t_test86_c_id[] = "@(#)$Id: t-test86.c,v 1.4 2008/04/11 23:25:20 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -14,6 +14,9 @@ static char t_test86_c_id[] = "@(#)$Id: t-test86.c,v 1.3 2008/02/26 00:45:18 msk
 #include <stdio.h>
 #include <arpa/nameser.h>
 
+/* libsm includes */
+#include <sm/string.h>
+
 /* libdkim includes */
 #include "dkim.h"
 #include "t-testdata.h"
@@ -86,10 +89,8 @@ main(int argc, char **argv)
 	dkim_policy_t pcode;
 	DKIM_STAT status;
 	dkim_query_t qtype = DKIM_QUERY_FILE;
-	time_t fixed_time;
 	DKIM *dkim;
 	DKIM_LIB *lib;
-	dkim_sigkey_t key;
 	unsigned char hdr[MAXHEADER + 1];
 
 	printf("*** relaxed/simple rsa-sha256 verifying subdomain with i=/d= mismatch and \"discardable\" policy\n");
