@@ -7,7 +7,7 @@
 #define _UTIL_H_
 
 #ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.15 2008/01/23 03:11:49 msk Exp $";
+static char util_h_id[] = "@(#)$Id: util.h,v 1.16 2008/01/31 00:23:31 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -20,6 +20,8 @@ static char util_h_id[] = "@(#)$Id: util.h,v 1.15 2008/01/23 03:11:49 msk Exp $"
 
 /* prototypes */
 extern int dkim_addrcmp __P((u_char *, u_char *));
+extern int dkim_check_dns_reply __P((unsigned char *ansbuf, size_t anslen,
+                                     int xclass, int xtype));
 extern void dkim_collapse __P((u_char *));
 extern bool dkim_hdrlist __P((u_char *, size_t, u_char **, bool));
 extern int dkim_hexchar __P((int c));
